#ifndef LIBMCB_H
#define LIBMCB_H

#ifdef __WINNT__
#include <windows.h>
#include "elvees_pci_public.h"
#include "elvees_pci_user.h"
#endif

#include "elvees_mcb03_regs.h"
#include "elvees_mcb03_bits.h"

#ifdef __cplusplus
extern "C" {
#endif

//!
//! Инициализация библиотеки доступа к микросхеме
//!
int libpe_init(void);

//!
//! Корректное отключение библиотеки доступа
//!
void libpe_close(void);

//!
//! Чтение участка памяти (в том числе регистров) из адресного
//! пространства микросхемы.
//! \param buffer указатель на буфер, в котором первым 32-хбитным элементом
//! должен быть адрес начала участка памяти, остальная часть буфера может
//! быть произвольной.
//! \param size размер буфера в байтах, включая первый элемент (адрес). Из-за
//! особенностей организации доступа через PCI параметр size должен
//! содержать значение, выравненное на 4, два младших бита всегда игнорируются.
//! \return количество успешно считанных байтов.
//!
int libpe_read(void *buffer, size_t size);

//!
//! Запись участка памяти (в том числе регистров) в адресное
//! пространство микросхемы.
//! \param buffer указатель на буфер, в котором первым 32-хбитным элементом
//! должен быть адрес начала участка памяти, остальная часть буфера должна
//! содержать данные для записи.
//! \param size размер буфера в байтах, включая первый элемент (адрес). Из-за
//! особенностей организации доступа через PCI параметр size должен
//! содержать значение, выравненное на 4, два младших бита всегда игнорируются.
//! \return количество успешно записанных байтов.
//!
int libpe_write(void *buffer, size_t size);

//!
//! Возвращает указатель на начало адресного пространства микросхемы (только под
//! Linux). Особенностью драйвера под Linux является то, что память микросхемы
//! отображается в виртуальное пространство процесса, благодаря чему
//! возможен доступ к памяти микросхемы напрямую по указателю. Этот метод при
//! правильном использовании может дать большую производительность
//! пользовательской программе, при этом также могут использоваться
//! функции \ref libpe_read и \ref libpe_write.
//! При использовании доступа по указателю необходимо также учитывать
//! особенности работы контроллера PCI: при считывании одного слова (или
//! байта) всегда происходит считывание 16 слов. Таким образом могут
//! быть сброшены некоторые биты в регистрах, которые пользователь
//! не намеревался читать (имеются в виду статусные биты, сбрасываемые
//! чтением). Сбрасываться иногда могут даже биты в одном регистре,
//! если значение регистра копируется побайтно, например, с помощью
//! функции memcpy.
//! \return указатель на начало адресного пространства микросхемы в виртуальном
//! пространстве процесса.
//!
void *libpe_raw_pointer_linux(void);

#ifdef __cplusplus
}
#endif

#endif // LIBMCB_H

